package com.ozs.web.controller.base;

import com.ozs.common.core.controller.BaseController;
import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.core.page.TableDataInfo;
import com.ozs.common.utils.StringUtils;
import com.ozs.base.domain.BaseSupplier;
import com.ozs.base.service.BaseSupplierService;
import com.ozs.common.utils.poi.ExcelUtil;
import com.ozs.system.domain.SysConfig;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 供应商管理
 *
 * @author sunhh
 */
@Api("供应商管理")
@RestController
@RequestMapping("/base/supplier")
public class BaseSupplierController extends BaseController {

    @Autowired
    private BaseSupplierService baseSupplierService;

    @ApiOperation("新增供应商户")
    @PostMapping("/insertBaseSupplier")
    public AjaxResult insertBaseSupplier(BaseSupplier baseSupplier) {
        if (StringUtils.isNull(baseSupplier) || StringUtils.isNull(baseSupplier.getSupplierName())) {
            return error("供应商名称不能为空");
        }
        return toAjax(baseSupplierService.insertBaseSupplier(baseSupplier));
    }

    @ApiOperation("删除供应商户")
    @PostMapping("/deleteBaseSupplier")
    public AjaxResult deleteBaseSupplier(BaseSupplier baseSupplier) {
        if (StringUtils.isNull(baseSupplier) || StringUtils.isNull(baseSupplier.getId())) {
            return error("删除ID不能为空");
        }
        return toAjax(baseSupplierService.deleteBaseSupplier(baseSupplier.getId()));
    }

    @ApiOperation("修改供应商户")
    @PostMapping("/updateBaseSupplier")
    public AjaxResult updateBaseSupplier(BaseSupplier baseSupplier) {
        if (StringUtils.isNull(baseSupplier) || StringUtils.isNull(baseSupplier.getId())) {
            return error("修改数据及ID不能为空");
        }
        return toAjax(baseSupplierService.updateBaseSupplier(baseSupplier));
    }

    @ApiOperation("查询供应商户")
    @PostMapping("/selectBaseSupplier")
    public TableDataInfo selectBaseSupplier(BaseSupplier baseSupplier) {
        List<BaseSupplier> baseSupplierList = baseSupplierService.selectBaseSupplier(baseSupplier);
        return getDataTable(baseSupplierList);
    }
}
